from io import BytesIO
from typing import Optional, Any, Tuple, Dict, Union, List, Iterable

try:
    from typing import Self, Annotated, TypedDict
except ImportError:
    from typing_extensions import Self, Annotated, TypedDict

PdfObject = Union[str, BytesIO]
PdfObjects = Iterable[PdfObject]


__all__ = [
    Optional,
    Any,
    Tuple,
    Dict,
    Self,
    Annotated,
    TypedDict,
    Union,
    List,
    Iterable,
    PdfObject,
    PdfObjects,
]



from typing import Optional, List, Tuple

from pypdf import DocumentInformation, PageObject

from pdfconduit.utils._permissions import Permissions
from pdfconduit.utils.typing import TypedDict


class SecurityDict(TypedDict):
    key: str
    value: int


class DimensionsDict(TypedDict):
    w: float
    h: float


SizeTuple = Tuple[float, float]

Metadata = Optional[DocumentInformation]

Resources = List[PageObject]


class InfoAllDict(TypedDict):
    encrypted: bool
    pages: int
    metadata: Metadata
    size: SizeTuple
    rotate: int
    permissions: Optional[Permissions]
    images_count: int


__all__ = [
    "SecurityDict",
    "DimensionsDict",
    "SizeTuple",
    "Metadata",
    "Resources",
    "InfoAllDict",
]
